@@ -7,8 +7,9 @@
 --   the GNU General Public License version 2 or later.
 --
 
--- grant access to different use for maximum priviledge separation
-GRANT INSERT, UPDATE, SELECT ON Resource, Resource_id_seq, Statement, Vote,
-	Member, Message, Item, Possession
+-- grant access to different user for maximum priviledge separation
+GRANT INSERT, UPDATE, SELECT ON Resource, Statement, Vote, Member,
+	Message, Item, Possession
 TO samizdat;
+GRANT USAGE, UPDATE, SELECT ON Resource_id_seq TO samizdat;
 GRANT INSERT, SELECT ON Moderation TO samizdat;
