@@ -1,6 +1,6 @@
 # Samizdat engine exceptions
 #
-#   Copyright (c) 2002-2006  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2008  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -10,9 +10,6 @@
 
 require 'samizdat/engine'
 
-# raised for syntax errors in Squish statements
-class ProgrammingError < RuntimeError; end
-
 # raised when non-existent resource is requested
 class ResourceNotFoundError < RuntimeError; end
 
@@ -24,3 +21,9 @@ class AuthError < UserError; end
 
 # raised when account is blocked for email confirmation
 class AccountBlockedError < UserError; end
+
+# raised on suspicion of spamming
+class SpamError < UserError; end
+
+# raised on attempt to re-raise same moderation request
+class ModerationRequestExistsError < UserError; end
