@@ -2,7 +2,7 @@
 #
 # Samizdat RDF storage tests
 #
-#   Copyright (c) 2002-2005  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2008  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -46,17 +46,19 @@ USING PRESET NS}
     assert_equal 'SELECT', query.key
     assert_equal :select, query.type
     assert_equal %w[?msg ?title ?name ?date ?rating], query.nodes
-    assert query.pattern.include?(["#{@ns['dc']}title", "?msg", "?title"])
+    assert query.pattern.include?(["#{@ns['dc']}title", "?msg", "?title", nil])
     assert_equal '?rating >= -1', query.literal
     assert_equal '?rating', query.order
     assert_equal 'DESC', query.order_dir
     assert_equal @ns['s'], query.ns['s']
 
     # transform_pattern
-    assert_equal config['map']['dc::title'], Hash[*query.c[0][1]]
-    assert_equal [[0, 1]], query.pm['?title']
+    sm = query.sql_mapper
+    map = sm.clauses[0][:object]
+    assert_equal config['map']['dc::title'], { map[:table] => map[:field] }
+    assert_equal [ { :clause => 0, :role => :object } ], sm.nodes['?title'][:positions]
     # todo: check jc
-    assert query.b.include?('?title')
+    assert sm.nodes['?title'][:bindings].first
 
     # query result
     begin
@@ -93,16 +95,18 @@ USING dc FOR #{@ns['dc']}
     assert_equal :assert, query.type
     assert_equal [['?msg'], {'?title' => "'0'", '?content' => "'1'"}],
       query.nodes
-    assert query.pattern.include?(["#{@ns['dc']}title", "?msg", "?title"])
+    assert query.pattern.include?(["#{@ns['dc']}title", "?msg", "?title", nil])
     assert_equal @ns['s'], query.ns['s']
     assert_equal "'Test Message'", query.substitute_literals("'0'")
     assert_equal "'Some text.'", query.substitute_literals("'1'")
 
     # transform_pattern
-    assert_equal config['map']['dc::creator'], Hash[*query.c[0][1]]
-    assert_equal [[0, 1]], query.pm["1"]
+    sm = query.sql_mapper
+    map = sm.clauses[0][:object]
+    assert_equal config['map']['dc::creator'], { map[:table] => map[:field] }
+    assert_equal [ { :clause => 0, :role => :object } ], sm.nodes['1'][:positions]
     # todo: check jc
-    assert query.b.include?('?title')
+    assert sm.nodes['1'][:bindings].first
 
     # todo: check assert
   end
@@ -123,14 +127,19 @@ USING s FOR #{@ns['s']}}
     assert_equal 'SELECT', query.key
     assert_equal :select, query.type
     assert_equal %w[?msg], query.nodes
-    assert query.pattern.include?(["#{@ns['s']}inReplyTo", "?msg", "?parent"])
+    assert query.pattern.include?(["#{@ns['s']}inReplyTo", "?msg", "?parent", nil])
     assert_equal @ns['s'], query.ns['s']
 
     # transform_pattern
-    assert_equal config['map']['s::inReplyTo'], Hash[*query.c[0][1]]
-    assert_equal [[0, 1]], query.pm['?parent']
+    sm = query.sql_mapper
+    map = sm.clauses[0][:object]
+    assert_equal config['map']['s::inReplyTo'], { map[:table] => map[:field] }
+    assert_equal [ { :clause => 0, :role => :object } ], sm.nodes['?parent'][:positions]
     # todo: check jc
-    assert query.b.include?('?parent')
+    assert sm.nodes['?parent'][:bindings].first
+
+    # dangling blank node
+    assert sm.where =~ /\b#{sm.nodes['?parent'][:bindings].first} IS NOT NULL\b/
 
     # query result
     begin
@@ -144,9 +153,46 @@ USING s FOR #{@ns['s']}}
       assert false, "select with query text raised #{$!.class}: #{$!}"
     end
     assert sql1 == sql2
+  end
 
-    # dangling blank node
-    assert query.jc.grep(/\A#{query.b['?parent']} IS NOT NULL\z/).size > 0
+  def test_external_resource_no_self_join
+    # initialize
+    query_text = %{SELECT ?id WHERE (s::id focus::Translation ?id)}
+    begin
+      query = SquishQuery.new(query_text)
+    rescue
+      assert false, "SquishQuery initialization raised #{$!.class}: #{$!}"
+    end
+
+    # query parser
+    assert_equal 'SELECT', query.key
+    assert_equal :select, query.type
+    assert_equal %w[?id], query.nodes
+    assert query.pattern.include?(["#{@ns['s']}id", "#{@ns['focus']}Translation", "?id", nil])
+    assert_equal @ns['s'], query.ns['s']
+
+    # transform_pattern
+    sm = query.sql_mapper
+    map = sm.clauses[0][:object]
+    assert_equal config['map']['s::id'], { map[:table] => map[:field] }
+    assert_equal [ { :clause => 0, :role => :object } ], sm.nodes['?id'][:positions]
+    assert sm.nodes['?id'][:bindings].first
+
+    # no self join
+    assert_equal false, sm.from.include?('JOIN')
+
+    # query result
+    begin
+      sql1 = rdf.select(query)
+    rescue
+      assert false, "select with pre-parsed query raised #{$!.class}: #{$!}"
+    end
+    begin
+      sql2 = rdf.select(query_text)
+    rescue
+      assert false, "select with query text raised #{$!.class}: #{$!}"
+    end
+    assert sql1 == sql2
   end
 
   #def test_internal_resource
