@@ -10,8 +10,12 @@
 #
 # vim: et sw=2 sts=2 ts=8 tw=0
 
+ENV['SAMIZDAT_SITE'] ||= 'samizdat'
+ENV['SAMIZDAT_URI'] ||= '/'
+
 require 'test/unit'
 require 'test/tc_version'
 require 'test/tc_cache'
 require 'test/tc_storage'
-require 'test/tc_template'
+require 'test/tc_application_helper'
+require 'test/tc_message_helper'
