@@ -2,7 +2,7 @@
 #
 # Samizdat test suite utility methods
 #
-#   Copyright (c) 2002-2005  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2006  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -11,25 +11,20 @@
 # vim: et sw=2 sts=2 ts=8 tw=0
 
 require 'rexml/document'
+require 'rexml/xpath'
 
-def elements(element, xpath, attribute=nil)
-  element.elements.to_a(xpath).collect {|e|
+XHTML_NS = { 'h' => 'http://www.w3.org/1999/xhtml' }
+
+def elements(element, path, attribute=nil)
+  REXML::XPath.match(element, path, XHTML_NS).collect {|e|
     attribute ? e.attributes[attribute] : e.text.strip
   }
 end
 
-def text(element, xpath)
-  element.elements[xpath].texts.join.strip
-end
-
-def parse_page(html)
-  xhtml = Samizdat::Sanitize.new(config.xhtml).sanitize(html, false)
-  begin
-    doc = REXML::Document.new(xhtml)
-  rescue REXML::ParseException
-    assert false, "REXML raised #{$!.class}: #{$!}"
-  end
-  doc.root
+def text(element, path)
+  REXML::XPath.match(element, path, XHTML_NS).collect {|e|
+    e.texts.join.strip
+  }.join
 end
 
 def parse(html)
@@ -41,3 +36,7 @@ def parse(html)
   doc.root
 end
 
+def parse_page(html)
+  xhtml = Samizdat::Sanitize.new(config.xhtml).sanitize(html, false)
+  parse(xhtml)
+end
